//                                               -*- C++ -*-
/**
 *  @file  FrankCopulaFactory.hxx
 *  @brief Factory for FrankCopula distribution
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-10 16:43:31 +0200 (jeu, 10 mai 2007) $
 *  Id:      $Id: FrankCopulaFactory.hxx 434 2007-05-10 14:43:31Z dutka $
 */
#ifndef OPENTURNS_FRANKCOPULAFACTORY_HXX
#define OPENTURNS_FRANKCOPULAFACTORY_HXX

#include "OTprivate.hxx"
#include "DistributionImplementationFactory.hxx"
#include "FrankCopula.hxx"

BEGIN_NAMESPACE_OPENTURNS



/**
 * @class FrankCopulaFactory
 */
class FrankCopulaFactory
  : public DistributionImplementationFactory
{
public:

  /** Default constructor */
  FrankCopulaFactory();

  /** Virtual constructor */
  virtual FrankCopulaFactory * clone() const;

  /* Here is the interface that all derived class must implement */
  using DistributionImplementationFactory::build;

  FrankCopula * build(const NumericalSample & sample) const;
  FrankCopula * build(const NumericalPointCollection & parameters) const;
  FrankCopula * build() const;

private:
  // Compute Kendall's tau from Frank copula's parameter
  NumericalScalar KendallTauFromParameter(const NumericalScalar theta) const;

}; /* class FrankCopulaFactory */


END_NAMESPACE_OPENTURNS

#endif /* OPENTURNS_FRANKCOPULAFACTORY_HXX */
