//                                               -*- C++ -*-
/**
 *  @file  LogNormalFactory.hxx
 *  @brief Factory for LogNormal distribution
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012) $
 *  Id:      $Id: LogNormalFactory.hxx 2392 2012-02-17 18:35:43Z schueller $
 */
#ifndef OPENTURNS_LOGNORMALFACTORY_HXX
#define OPENTURNS_LOGNORMALFACTORY_HXX

#include "OTprivate.hxx"
#include "DistributionImplementationFactory.hxx"
#include "LogNormal.hxx"

BEGIN_NAMESPACE_OPENTURNS



/**
 * @class LogNormalFactory
 */
class LogNormalFactory
  : public DistributionImplementationFactory
{
public:

  /** Default constructor */
  LogNormalFactory();

  /** Virtual constructor */
  virtual LogNormalFactory * clone() const;

  /* Here is the interface that all derived class must implement */
  using DistributionImplementationFactory::build;

  LogNormal * build(const NumericalSample & sample) const;
  LogNormal * build(const NumericalPointCollection & parameters) const;
  LogNormal * build() const;

private:
  /* Compute the different sums needed by the likelihood maximization */
  static NumericalPoint ComputeMaximumLikelihoodSums(const NumericalScalar gamma,
                                                     const NumericalSample & sample);

  /* Compute the maximum likelihood constraint for the shift parameter \gamma */
  static NumericalScalar ComputeConstraint(const NumericalPoint & sums);

}; /* class LogNormalFactory */


END_NAMESPACE_OPENTURNS

#endif /* OPENTURNS_LOGNORMALFACTORY_HXX */
