#                                               -*- Autoconf -*-
#
#  ot_check_regex.m4
#
#  (C) Copyright 2005-2012 EDF-EADS-Phimeca
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2.1 of the License.
#
#  This library is distributed in the hope that it will be useful
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
#  @author: $LastChangedBy: schueller $
#  @date:   $LastChangedDate: 2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012) $
#  Id:      $Id: ot_check_regex.m4 2392 2012-02-17 18:35:43Z schueller $
#
#
#  This file is intended to be include in the configure.in file
#  of Open TURNS project to check whether reguler expressions are 
#  available on the platform.
#
# OT_CHECK_REGEX([ DIR = /usr ])
# ------------------------------
#
AC_DEFUN([OT_CHECK_REGEX],
[
 AC_ARG_WITH([regex],
  AC_HELP_STRING([--with-regex@<:@=DIR@:>@], [add regular expression support. @<:@]m4_default([$1], /usr)[@:>@]),
                 [], [withval=yes])

  WITH_REGEX=0

  # saving values for compilation variables
  saved_CPPFLAGS=$CPPFLAGS
  saved_LDFLAGS=$LDFLAGS
  saved_LIBS=$LIBS

  regex_default_path=m4_default([$1], /usr)
  if ! test x${withval} = xno
  then
    # ask for Regex support
    AC_MSG_NOTICE([checking whether regular expressions are here and working])

    # we're trying to find the correct Regex installation path
    regex_install_path=$regex_default_path
    test x${withval} = xyes || regex_install_path=$withval

    AC_MSG_CHECKING([Regex install path])
    test -d ${regex_install_path} || AC_MSG_ERROR([$regex_install_path: incorrect path])
    AC_MSG_RESULT([$regex_install_path])



    # we test the header file presence and usability
    regex_include_path=$regex_install_path/include
    REGEX_CPPFLAGS="-I${regex_include_path}"
    CPPFLAGS="${CPPFLAGS} ${REGEX_CPPFLAGS}"
    AC_LANG_PUSH(C)
    AC_CHECK_HEADERS([regex.h],
                     [regex_header_found=yes],
                     [regex_header_found=no],
                     [])
    AC_LANG_POP(C)
    test x${regex_header_found} = xno && AC_MSG_ERROR([Regex include file NOT FOUND])
    AC_SUBST(REGEX_CPPFLAGS)

    # we test the library file presence and usability
    regex_lib_path=$regex_install_path/lib
    regex_lib_name=c
    REGEX_LDFLAGS="-L${regex_lib_path}"
    REGEX_LIBS="-l${regex_lib_name}"
    LDFLAGS="${LDFLAGS} ${REGEX_LDFLAGS}"
    LIBS="${LIBS} ${REGEX_LIBS}"
    AC_SEARCH_LIBS([regexec], [$regex_lib_name], [regex_lib_found=yes], [regex_lib_found=no])
    if test x${regex_lib_found} = xno
    then
      # in mingw environnment, regex is not given by libc
      regex_lib_name=gnurx
      REGEX_LIBS="-l${regex_lib_name}"
      LIBS=$saved_LIBS
      LIBS="${LIBS} -l${regex_lib_name}" 
      # search regcomp rather than regexec symbol to avoid the result cached by autotools
      AC_SEARCH_LIBS([regcomp], [$regex_lib_name], [regex_lib_found=yes], [regex_lib_found=no])
    fi
    test x${regex_lib_found} = xno && AC_MSG_ERROR([Regex library NOT FOUND])
    AC_SUBST(REGEX_LDFLAGS)
    AC_SUBST(REGEX_LIBS)


    # after all tests are successful, we support Regex
    WITH_REGEX=1
    AC_MSG_NOTICE([Regex support is OK])

    # Propagate test into source files
    AC_DEFINE_UNQUOTED(HAVE_REGEX, $WITH_REGEX, [Support for regular expression library])

  else
    # no Regex support
    AC_MSG_NOTICE([No Regex support])
  fi

  # Propagate test into atlocal
  AC_SUBST(WITH_REGEX)

  # Propagate test into Makefiles...
  AM_CONDITIONAL(WITH_REGEX, test $WITH_REGEX = 1)

  # restoring saved values
  CPPFLAGS=$saved_CPPFLAGS
  LDFLAGS=$saved_LDFLAGS
  LIBS=$saved_LIBS

])
